API docs for “spamfighter.utils.registrator”

# Module s.u.registrator

Part of spamfighter.utils View Source

Декоратор регистрации, позволяющий получить текущий класс в функции, вызванной в теле класса.

Function | registrator | Декоратор регистраторов
Function | _implements | Undocumented

def registrator(f): (source)
Декоратор регистраторов

оборачивает методы которые затем могут вызываться в определении классов. При этом первым параметром в оборачиваемую функцию передается класс в определении которого она вызвана

Пример:

       @registrator
       def register(cls, *args, **kw):
           print "Class:", cls

       class Test(object):
           register()

выведет на экран <class '__main__.Test'>

def _implements(name, args, kw, classImplements): (source)
Undocumented